
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006001
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Charset
ETag
Encodings
Erlang
Fayland
JS
Luehrs
Oschwald
RESTful
Rolsky
Stevan
WebDAV
Webmachine
arity
charsets
webmachine
JavaScript
Little
stevan
Infinity
Interactive
Inc
Andreas
Marienborg
andreas
Andrew
Nelson
anelson
Arthur
Axel
fREW
Schmidt
frioux
Carlos
Fernando
Avila
Gratz
cafe
Dave
autarch
Lam
fayland
Gregory
goschwald
Jesse
doy
John
SJ
Anderson
genehack
Olaf
Alders
olaf
Thomas
Sibley
tsibley
lib
Web
Machine
I18N
en
Manual
Util
ContentNegotiation
FSM
States
Resource
BodyEncoding
